# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"gdown_unzip": "02_video2picture.ipynb",
         "pose_dis": "00_utils.ipynb",
         "waypoint": "00_utils.ipynb",
         "camera_projection": "01_camera_projection.ipynb",
         "get_images_from_video": "02_video2picture.ipynb",
         "robot_model_loader": "03_robot_model.ipynb",
         "whoami": "04_get_ip.ipynb",
         "get_key": "04_get_ip.ipynb",
         "get_xbee_address": "04_get_ip.ipynb",
         "get_xbee_address_boat": "04_get_ip.ipynb",
         "find_duckiepond_devices_yaml": "04_get_ip.ipynb"}

modules = ["utils.py",
           "camera_projection.py",
           "video2picture.py",
           "robot_model.py",
           "get_ip.py"]

doc_url = "https://ARG-NCTU.github.io/arg_robotics_tools/"

git_url = "https://github.com/ARG-NCTU/arg_robotics_tools/tree/master/"

def custom_doc_links(name): return None
